library(dplyr)
library(broom)

# PCA with Rotation Matrix Post-quant Template
# Enjoy! 
# cirwi005@fiu.edu

# This is meant to be used with simulated_STEM_data.rdata

simluated_data_pca_fit <- simluated_data_data |>
  select(zip_code_public_housing, parental_education, SAT_score, GPA, black_and_hispanic, female) |>
  scale() |>
  prcomp()


simluated_data_pca_fit |>  # plot the variance explained
  tidy(matrix = "eigenvalues") |>
  ggplot(aes(PC, percent)) +
  geom_col() + 
  scale_x_continuous(
    breaks = 1:6
  ) +
  scale_y_continuous(
    name = "variance explained",
    label = scales::label_percent(accuracy = 1)
  )  


arrow_style <- arrow(
  angle = 20, length = grid::unit(8, "pt"),
  ends = "first", type = "closed"
)

simluated_data_pca_fit |>  # plot the rotation matrix
  tidy(matrix = "rotation") |>
  pivot_wider(
    names_from = "PC", values_from = "value",
    names_prefix = "PC"
  ) |>
  ggplot(aes(PC1, PC2)) +
  geom_segment(
    xend = 0, yend = 0,
    arrow = arrow_style
  ) +
  geom_text(aes(label = column), hjust = 1) +
  xlim(-1.5, 0.5) + ylim(-1, 1) +
  coord_fixed()

simluated_data_pca_fit |>  # plot the rotation matrix
  tidy(matrix = "rotation") |>
  pivot_wider(
    names_from = "PC", values_from = "value",
    names_prefix = "PC"
  ) |>
  ggplot(aes(PC5, PC6)) +
  geom_segment(
    xend = 0, yend = 0,
    arrow = arrow_style
  ) +
  geom_text(aes(label = column), hjust = 1) +
  xlim(-1.5, 0.5) + ylim(-1, 1) +
  coord_fixed()


